from typing import Optional, List

import attr
from marshmallow_annotations.ext.attrs import AttrsSchema


@attr.s(auto_attribs=True, kw_only=True)
class CompanySummary:
    id: str = attr.ib()
    name: str = attr.ib()
    profile_url: str = attr.ib()
    business_id_fi: Optional[str] = None
    industry_code: Optional[str] = None
    industry_name: Optional[str] = None
    employee_names: List[str] = attr.ib(factory=list)


class CompanySummarySchema(AttrsSchema):
    class Meta:
        target = CompanySummary
        register_as_scheme = True



from typing import Optional, List

import attr
from marshmallow_annotations.ext.attrs import AttrsSchema


@attr.s(auto_attribs=True, kw_only=True)
class IndustrySummary:
    id: str = attr.ib()
    name: str = attr.ib()


class IndustrySummarySchema(AttrsSchema):
    class Meta:
        target = IndustrySummary
        register_as_scheme = True



from typing import Optional, List

import attr
from marshmallow_annotations.ext.attrs import AttrsSchema


@attr.s(auto_attribs=True, kw_only=True)
class PersonSummary:
    id: str = attr.ib()
    name: str = attr.ib()
    profile_url: str = attr.ib()
    headline: Optional[str] = None
    job_titles: List[str] = attr.ib(factory=list)
    company_names: List[str] = attr.ib(factory=list)
    description: Optional[str] = None
    location: Optional[str] = None

class PersonSummarySchema(AttrsSchema):
    class Meta:
        target = PersonSummary
        register_as_scheme = True



from typing import Optional

import attr
from marshmallow_annotations.ext.attrs import AttrsSchema


@attr.s(auto_attribs=True, kw_only=True)
class PostCommentSummary:
    person_name: str = attr.ib()
    post_comment_count: Optional[int] = None
    post_like_count: Optional[int] = None
    post_url: Optional[str] = []


class PostCommentSummarySchema(AttrsSchema):
    class Meta:
        target = PostCommentSummary
        register_as_scheme = True
